/*
--------------
NOTES FOR DEVS
--------------

If your predator has a limited capacity, it should have sprites for every interval of its size, rounded to the nearest whole number.
Example: If I have a snake predator who has a capacity of 3, I need sprites for snake-1, snake-2, and snake-3.

Capacity should always be a whole number.

Also max_size and min_size should never exceed capacity or the icon will break.

Don't use ranged mobs for vore mobs.


Argobarg's Edit:  Trying to make an "endo" hostile mob.  Duplicating the hostile/vore type for a hostile/endo.  Mostly so I can write my own icon update function for my catgirls.

An "endo" hostile mob type doesn't digest; instead, it should enter a docile state once it's full.  If it's then emptied, there should be a period of time before it starts looking for occupants again, allowing you to say, feed it a crewmember, take it to a containment thingie somewhere, then extract the crewmember and lock the mob in.

More of an inconvenience than a threat.

*/


/mob/living/simple_animal/hostile/endo
	name = "catgirl"
	desc = "It's a catgirl!"
	icon_dead = "catgirl-dead"
	icon_living = "catgirl"
	icon_state = "catgirl"
	icon = 'icons/mob/endo.dmi'
	var/baseicon = "catgirl" //For modified icon update function.  Should allow alternate things, like my sleeping catgirls.
	var/capacity = 1 // Zero is infinite. Do not set higher than you have icons to update.
	var/max_size = 1 // Max: 2
	var/min_size = 0.25 // Min: 0.25
	var/picky = 0 // Can eat undigestable prey // Not that this matters, since endo, but, well.
	var/fullness = 0
	swallowTime = 3 // Hungry little bastards.

	// By default, this is what most vore mobs are capable of.
	response_help = "pets"
	response_disarm = "gently pushes aside"
	response_harm = "hits"
	speed = 4
	harm_intent_damage = 0
	melee_damage_lower = 0
	melee_damage_upper = 0  //Note to self, figure out a way for mobs to only deal damage to targets they DON'T wanna eat.
	attacktext = "baps"
	attack_sound = 'sound/weapons/throwtap.ogg'
	min_oxy = 0
	max_oxy = 0
	min_tox = 0
	max_tox = 0
	min_co2 = 0
	max_co2 = 0
	min_n2 = 0
	max_n2 = 0
	minbodytemp = 0
	//maxbodytemp = 370
	heat_damage_per_tick = 15
	cold_damage_per_tick = 10
	unsuitable_atoms_damage = 10
	var/sizeInterval = 1  //Might be able ta use this fer something.

/mob/living/simple_animal/hostile/endo/update_icons()
	if(stat == DEAD)
		return

	if(capacity)
		fullness = 0
		for(var/I in vore_organs)
			var/datum/belly/B = vore_organs[I]
			for(var/mob/living/M in B.internal_contents)
				fullness += M.size_multiplier
				//world << "[baseicon]-[fullness]"  //Found that it calls for a zero before the point.  So like, "catgirl-0.5"
		fullness = round(fullness, sizeInterval) //Oh hey.  Now will show a belly when stuffed with enough micros.
		if(fullness)
			if (fullness > capacity) // Player controlled.
				icon_state = "[baseicon]-[capacity]"
			else
				icon_state = "[baseicon]-[fullness]"
		else
			icon_state = baseicon
	..()

/mob/living/simple_animal/hostile/endo/New()

	if(!vore_organs.len)
		var/datum/belly/B = new /datum/belly(src)
		B.immutable = 1
		B.name = "Stomach"
		B.inside_flavor = "It appears to be rather warm and wet. Makes sense, considering it's inside \the [name]."
		B.digest_mode = "Hold" // Endo mobs!
		vore_organs[B.name] = B
		vore_selected = "Stomach"
		B.vore_verb = "swallow"
		B.emote_lists[DM_HOLD] = list(
			"The insides knead at you gently for a moment.",
			"Your captor takes a deep breath and sighs, shifting you somewhat.",
			"During a moment of quiet, breathing becomes the most audible thing.",
			"The warm slickness surrounds and kneads on you.")

		B.emote_lists[DM_DIGEST] = list()
	..()

/mob/living/simple_animal/hostile/endo/AttackingTarget()
	if(isliving(target_mob.loc)) //They're inside a mob, maybe us, ignore!
		return

	if(!isliving(target_mob)) //Can't eat 'em if they ain't alive. Prevents eating borgs/bots.
		..()
		return

	if(picky && !target_mob.digestable) //Don't eat people with nogurgle prefs
		..()
		return

	// Is our target edible and standing up?
	if(target_mob.canmove && target_mob.size_multiplier >= min_size && target_mob.size_multiplier <= max_size && !(target_mob in prey_exclusions))
		if(prob(50))
			target_mob.Weaken(5)
			target_mob.visible_message("<span class='danger'>\the [src] pounces on \the [target_mob]!</span>!")
			animal_nom(target_mob)
			LoseTarget()
			return
		else
			..()

	if(!target_mob.canmove && target_mob.size_multiplier >= min_size && target_mob.size_multiplier <= max_size && !(target_mob in prey_exclusions))
		if(!capacity || (target_mob.size_multiplier + fullness) <= capacity)
			stance = HOSTILE_STANCE_EATING
			stop_automated_movement = 1
			animal_nom(target_mob)
			LoseTarget()
			return
	..()

/mob/living/simple_animal/hostile/endo/death()
	for(var/I in vore_organs)
		var/datum/belly/B = vore_organs[I]
		B.release_all_contents() // When your stomach is empty
	..() // then you have my permission to die.

/*
// ------- Big Preds ------- //

/mob/living/simple_animal/hostile/endo/large
	name = "giant snake"
	desc = "Snakes. Why did it have to be snakes?"
	icon = 'icons/mob/vore64x64.dmi'
	icon_dead = "snake-dead"
	icon_living = "snake"
	icon_state = "snake"
	old_x = -16
	old_y = -16
	pixel_x = -16
	pixel_y = -16
	maxHealth = 200
	health = 200
	
*/